debug

package module
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 25, 2022 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package debug contains some functions helpful for debugging go programs.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Dump

func Dump(i interface{}, o ...io.Writer)

Dump renders a variable as a string, just like SDump, but then writes it to one or more io.Writers (or, by default,to os.Stderr) This function is NOT intended to be used in final or production code ... it is simply to visualize the contents of a variable. The format of the output is not guaranteed to remain the same.

func SDump

func SDump(i interface{}) string

SDump renders a variable as a string, in a readable form. Think Data::Dumper in perl. Clearer than fmt.Sprintf("%+v"...) This function is NOT intended to be used in final or production code ... it is simply to visualize the contents of a variable. The format of the output is not guaranteed to remain the same. Note: Only includes public members ...

Types

This section is empty.

Jump to